==> haskell-gi-gtk-hs-0.3.16-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-gtk-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-gtk-hs
version:              0.3.16
visibility:           public
id:                   gi-gtk-hs-0.3.16-5rr7NFFxNSLIOdOmxE8YtL
key:                  gi-gtk-hs-0.3.16-5rr7NFFxNSLIOdOmxE8YtL
license:              LGPL-2.1-only
maintainer:           mail@jonasplatte.de
author:
    Jonas Platte,
    Duncan Coutts,
    Axel Simon,
    Hamish Mackenzie,
    Iñaki García Etxebarria

homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

description:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

category:             Graphics
abi:                  4cc08442c53fb9dfa48c764f3bfb497b
exposed:              True
exposed-modules:
    Data.GI.Gtk Data.GI.Gtk.BuildFn Data.GI.Gtk.ComboBox
    Data.GI.Gtk.ModelView.CellLayout Data.GI.Gtk.ModelView.CustomStore
    Data.GI.Gtk.ModelView.ForestStore Data.GI.Gtk.ModelView.SeqStore
    Data.GI.Gtk.ModelView.TreeModel Data.GI.Gtk.ModelView.Types
    Data.GI.Gtk.Threading Data.GI.Gtk.Widget

import-dirs:          /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-gtk-hs
hs-libraries:         HSgi-gtk-hs-0.3.16-5rr7NFFxNSLIOdOmxE8YtL
depends:
    base-4.17.2.1 base-compat-0.12.2-3peTS4EQIw912qC0ETmbL5
    containers-0.6.7 gi-gdk-3.0.26-Fo4yTFEgz70K8GbDYmBMPJ
    gi-gdkpixbuf-2.0.32-6BcoX8Du1gZ6GJ1SP0dUIK
    gi-glib-2.0.29-7ccQeiuxhmBCvFsIItl4ZT
    gi-gobject-2.0.30-5fFg0UWjA3eLtjv7VP9Kk7
    gi-gtk-3.0.39-JAP4hV3FaKIE16r9wbtIkn
    haskell-gi-base-0.26.6-8Q7bG4vZp6hk1q5uA8ktg mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gi-gtk-hs/html/gi-gtk-hs.haddock
haddock-html:         /usr/share/doc/haskell-gi-gtk-hs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-gtk-hs-0.3.16-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-gtk-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-gtk-hs
version:              0.3.16
visibility:           public
id:                   gi-gtk-hs-0.3.16-G1UCghEuOIyDbIFuh0q7ic
key:                  gi-gtk-hs-0.3.16-G1UCghEuOIyDbIFuh0q7ic
license:              LGPL-2.1-only
maintainer:           mail@jonasplatte.de
author:
    Jonas Platte,
    Duncan Coutts,
    Axel Simon,
    Hamish Mackenzie,
    Iñaki García Etxebarria

homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

description:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

category:             Graphics
abi:                  fd8885bb7f84cadbc69fbadee3154245
exposed:              True
exposed-modules:
    Data.GI.Gtk Data.GI.Gtk.BuildFn Data.GI.Gtk.ComboBox
    Data.GI.Gtk.ModelView.CellLayout Data.GI.Gtk.ModelView.CustomStore
    Data.GI.Gtk.ModelView.ForestStore Data.GI.Gtk.ModelView.SeqStore
    Data.GI.Gtk.ModelView.TreeModel Data.GI.Gtk.ModelView.Types
    Data.GI.Gtk.Threading Data.GI.Gtk.Widget

import-dirs:          /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-gtk-hs
hs-libraries:         HSgi-gtk-hs-0.3.16-G1UCghEuOIyDbIFuh0q7ic
depends:
    base-4.17.2.1 base-compat-0.12.2-3peTS4EQIw912qC0ETmbL5
    containers-0.6.7 gi-gdk-3.0.26-AjUZWDk9WBwBa5IC1II5Ci
    gi-gdkpixbuf-2.0.32-BZSG7YZ0UTwIWsFUvpAz9B
    gi-glib-2.0.29-EYaeI1GVCnN15c972visYL
    gi-gobject-2.0.30-3i5FuHOKrHd4VSXyLY4e1j
    gi-gtk-3.0.39-BBPUeFrK3LOFAx59n0BMAL
    haskell-gi-base-0.26.6-8Q7bG4vZp6hk1q5uA8ktg mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gi-gtk-hs/html/gi-gtk-hs.haddock
haddock-html:         /usr/share/doc/haskell-gi-gtk-hs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
